FFmpegExecution class

Represents an ongoing FFmpeg execution.

Constructors

FFmpegExecution({required String command, required int executionId, required DateTime startTime})

Properties

command ↔ String
getter/setter pair
executionId ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited