Statistics class

Constructors

Statistics(int executionId, int videoFrameNumber, double videoFps, double videoQuality, int size, int time, double bitrate, double speed)

Properties

bitrate ↔ double
getter/setter pair
executionId ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int
getter/setter pair
speed ↔ double
getter/setter pair
time ↔ int
getter/setter pair
videoFps ↔ double
getter/setter pair
videoFrameNumber ↔ int
getter/setter pair
videoQuality ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited